A class responsible for the simulation data to disk.
This class can be subclasses to provide advanced data writing to other data sources. This should also be subclassed if the agent and resource classes are subclasses, to write any additional fields to the data source.
results_directoryThe folder where the simulation results are written to
agent_filenameThe location where the agents are written to
resource_filenameThe location where the resources are written to
new()Creates a new data writer object that has optional paths for data files.
data_writer$new(
results_directory = "results",
agent_filename = "agents.csv",
resource_filename = "resources.csv"
)write()Takes a state an the name of a village and writes the agents and resources to disk