R6 Class representing data that's external from resources and agents

It contains a single variable, 'events' for when the data holds a list of events

Public fields

events

Any events that need to be tracked

Methods


Method new()

Creates a new model_data object

Usage

Returns

A new model data object


Method clone()

The objects of this class are cloneable with this method.

Usage

model_data$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.