| simulation | R Documentation |
Advances one or more villages through time
run_model()Runs the simulation
Creates a new Simulation instance
lengthThe total number of time steps that the simulation runs for
villagesA list of villages that the simulator will run
writerAn instance of a data_writer class for writing village data to disk
new()Creates a new simulation object to control the experiment
simulation$new(length, villages, writer = villager::data_writer$new())
lengthThe number of steps the simulation takes
villagesA list of villages that will be simulated
writerThe data writer to be used with the villages Runs the simulation
run_model()simulation$run_model()
None
clone()The objects of this class are cloneable with this method.
simulation$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.