This is an object that represents the state of a village at a particular time.
This class acts as a type of record that holds the values of the different village variables. This class can be subclassed to include more variables that aren't present.
Creates a new State
stepThe time step that the state is relevant to
agent_statesA list of agent states
resource_statesA list of resource states
new()Initializes all of the properties in the state to the ones passed in. This should be called by subclasses during initialization.
village_state$new(
step = 0,
agent_states = vector(),
resource_states = vector()
)