Learn R Programming

villager (version 2.0.0)

model_data: Model Data

Description

R6 Class representing data that's external from resources and agents

It contains a single variable, 'events' for when the data holds a list of events

Arguments

Public fields

events

Any events that need to be tracked

Methods


Method new()

Creates a new model_data object

Usage

model_data$new()

Returns

A new model data object


Method clone()

The objects of this class are cloneable with this method.

Usage

model_data$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.