This is an object that represents a single resource.
initialize()Create a new resource
as_table()Represents the current state of the resource as a tibble
Creates a new resource.
nameThe name of the resource
quantityThe quantity of the resource that exists
new()Creates a new resource object
resource$new(name = NA, quantity = 0)nameThe name of the resource
quantityThe quantity present Returns a data.frame representation of the resource
as_table()resource$as_table()A data.frame of resources
clone()The objects of this class are cloneable with this method.
resource$clone(deep = FALSE)deepWhether to make a deep clone.