Learn R Programming

villager (version 2.0.0)

simulation: simulation

Description

Advances one or more villages through time

Arguments

Methods

run_model()

Runs the simulation

Creates a new Simulation instance

Public fields

length

The total number of time steps that the simulation runs for

villages

A list of villages that the simulator will run

writer

An instance of a data_writer class for writing village data to disk

Methods


Method new()

Creates a new simulation object to control the experiment

Usage

simulation$new(length, villages, writer = villager::data_writer$new())

Arguments

length

The number of steps the simulation takes

villages

A list of villages that will be simulated

writer

The data writer to be used with the villages Runs the simulation


Method run_model()

Usage

simulation$run_model()

Returns

None


Method clone()

The objects of this class are cloneable with this method.

Usage

simulation$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.