| village_manager | R Documentation |
This object manages all of the villages. It acts as an interface to them
initialize()Creates a new manager
get_villages()Gets all of the villages that the manager has
get_village()Retrieves a specific village from the manager, by name
add_village()Adds a village to the manager
villagesA list of village objects Creates a new, village manager
new()Get a new instance of a village_manager Gets all of the managed villages
village_manager$new(villages)
get_villages()village_manager$get_villages()
A list of resources Gets a village given a village name
get_village()village_manager$get_village(name)
nameThe name of the requested village
A village object Adds a village to the manager.
add_resource()village_manager$add_resource(...)
...The villages to add
None
clone()The objects of this class are cloneable with this method.
village_manager$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.